diff src/intl-win32.c @ 1111:184461bc8de4

[xemacs-hg @ 2002-11-18 06:52:23 by ben] warning fixes, etc. * s/cygwin32.h: -fvtable-thunks is obsolete in GCC 3 and generates warnings. * s/mingw32.h: * s/windowsnt.h: Comment fixes. * emodules.h: Fix warnings from redefining symbols. * eval.c: Fix C++ errors -- no automatic casting between function pointers and void *, function declarations inside of functions not allowed. * event-Xt.c (emacs_Xt_enqueue_focus_event): Warning fixes. * fileio.c (Ffile_truename): Warning fixes. Use LOCAL_TO_WIN32_FILE_FORMAT rather than duplicating it. * glyphs-x.c: Fix style. * intl-auto-encap-win32.c: * intl-auto-encap-win32.h: * intl-encap-win32.c: * intl-encap-win32.c (qxeRegConnectRegistry): * syswindows.h (RegConnectRegistry): DdeCreateStringHandle needs to be manual due to new Cygwin bug. * intl-win32.c: wcslen/wcscmp don't seem to exist under G++ 3, Cygwin. * lisp.h: * lisp-union.h: * lisp-disunion.h: * process-unix.c (unix_send_process): Ugh, C needs volatile and C++ must not have volatile. Remove previous volatile hacks, which don't seem to be working any more. * sheap.c (STATIC_HEAP_SLOP): Try to get a working Cygwin build with old unexec. * sheap.c (more_static_core): No NL's in literals allowed. * symbols.c (Fset): Fix C++ errors. * syswindows.h: Fix Cygwin complaints now that some missing structs have been added. aclocal.m4: Disable shared library modules under Cygwin for the moment, since we need some more tricky coding done and I don't have the time right now. configure.in, configure.usage: code-files.el, loadhist.el: Fix warnings. package-get.el: Fix warnings. NOTE: This was already fixed awhile ago, but reverted by Steve Y. Please be careful. postgresql/Makefile.in.in: Removed. Move common stuff into modues/common/Makefile.common. (Also add extraclean target and a couple of other fixes in that file.) postgresql/configure.ac: Extract out common configure stuff into modules/common/configure-{pre,post}.ac. postgresql/postgresql.c: Fix warning. ldap/Makefile.in.in: Removed. Move common stuff into modues/common/Makefile.common. (Also add extraclean target and a couple of other fixes in that file.) ldap/configure.ac: Extract out common configure stuff into modules/common/configure-{pre,post}.ac. common/Makefile.common: Common stuff is here.
author ben
date Mon, 18 Nov 2002 06:53:08 +0000
parents 79c6ff3eef26
children e22b0213b713
line wrap: on
line diff
--- a/src/intl-win32.c	Sun Nov 17 22:53:08 2002 +0000
+++ b/src/intl-win32.c	Mon Nov 18 06:53:08 2002 +0000
@@ -1300,7 +1300,9 @@
   return Qnil;
 }
 
-Lisp_Object 
+#if 0 /* Unused */
+
+static Lisp_Object 
 mswindows_get_registry_charset (Ibyte *registry)
 {
   Lisp_Object charset_tail;
@@ -1321,6 +1323,8 @@
   return charset;
 }
 
+#endif /* 0 */
+
 
 
 #if 0 /* #### from Emacs 20.6; consider porting */
@@ -1610,7 +1614,38 @@
 
 #ifdef CYGWIN
 
-/* based on newlib strncpy, strcpy */
+/* based on newlib str*() */
+
+#ifndef HAVE_WCSCMP
+
+int
+wcscmp (const wchar_t *s1, const wchar_t *s2)
+{
+  while (*s1 != '\0' && *s1 == *s2)
+    {
+      s1++;
+      s2++;
+    }
+
+  return *s1 - *s2;
+}
+
+#endif /* not HAVE_WCSCMP */
+
+#ifndef HAVE_WCSLEN
+
+size_t
+wcslen (const wchar_t *str)
+{
+  const wchar_t *start = str;
+
+  while (*str)
+    str++;
+
+  return str - start;
+}
+
+#endif /* not HAVE_WCSLEN */
 
 wchar_t *
 wcsncpy (wchar_t *dst0, const wchar_t *src0, size_t count)